[−][src]Module yew_stdweb::agent
This module contains types to support multi-threading in Yew.
Structs
| AgentLink | Link to agent's scope for creating callbacks. |
| AgentScope | This struct holds a reference to a component and to a global scheduler. |
| Context | Create a single instance in the current thread. |
| Dispatcher | A newtype around a bridge to indicate that it is distinct from a normal bridge |
| Global | Create a single instance in a browser. |
| HandlerId | Id of responses handler. |
| Job | Create an instance in the current thread. |
| Private | Create a new instance for every bridge. |
| PrivateBridge | A connection manager for components interaction with workers. |
| Public | Create a single instance in a tab. |
| PublicBridge | A connection manager for components interaction with workers. |
Enums
| AgentLifecycleEvent | Local Agent messages |
Traits
| Agent | Declares the behavior of the agent. |
| Bridge | Bridge to a specific kind of worker. |
| Bridged | This trait allows registering or getting the address of a worker. |
| Dispatchable | Marker trait to indicate which Discoverers are able to be used with dispatchers. |
| Dispatched | This trait allows the creation of a dispatcher to an existing agent that will not send replies when messages are sent. |
| Packed | Message packager, based on serde::Serialize/Deserialize |
| Responder | Defines communication from Worker to Consumers |
| Threaded | Implements rules to register a worker in a separate thread. |