[]Struct yew_stdweb::events::BlurEvent

pub struct BlurEvent(_);

The BlurEvent is fired when an element has lost focus. The main difference between this event and focusout is that only the latter bubbles.

(JavaScript docs)