[]Struct yew_stdweb::events::DragEndEvent

pub struct DragEndEvent(_);

The dragend event is fired when a drag operation is being ended (by releasing a mouse button or hitting the escape key).

(JavaScript docs)