[]Struct yew_stdweb::events::DragEvent

pub struct DragEvent(_);

The drag event is fired every few hundred milliseconds as an element or text selection is being dragged by the user.

(JavaScript docs)