[]Struct yew_stdweb::events::DragOverEvent

pub struct DragOverEvent(_);

The dragover event is fired when an element or text selection is being dragged over a valid drop target (every few hundred milliseconds).

(JavaScript docs)