[]Struct yew_stdweb::events::FocusEvent

pub struct FocusEvent(_);

The FocusEvent is fired when an element has received focus. The main difference between this event and focusin is that only the latter bubbles.

(JavaScript docs)