[]Struct yew_stdweb::events::KeyPressEvent

pub struct KeyPressEvent(_);

The KeyPressEvent is fired when a key is pressed down. It's only fired for keys which produce a character value.

(JavaScript docs)