[]Struct yew_stdweb::events::PointerCancelEvent

pub struct PointerCancelEvent(_);

The PointerCancelEvent is fired when a pointer will no longer produce events (for example the device is deactivated), or if the pointer starts a gesture after a pointerdown event (for example panning, zooming, or drag and drop)

(JavaScript docs)