[]Struct yew_stdweb::events::PointerOutEvent

pub struct PointerOutEvent(_);

The PointerOutEvent is fired when the pointer moves out of the hit test boundaries of an element. This can include when a finger leaves a touch screen or a pen leaves the detectable hover range.

(JavaScript docs)