[]Struct yew_stdweb::events::TouchEnter

pub struct TouchEnter(_);

The TouchEnter event is fired when a touch point is moved onto the interactive area of an element.

Warning: This event was a proposal in an early version of the specification and has not been implemented. Do not rely on it.

(JavaScript docs)