[−][src]Struct yew_stdweb::services::interval::IntervalService
A service to send messages on every elapsed interval.
Methods
impl IntervalService[src]
pub fn new() -> Self[src]
Creates a new service instance connected to App by provided sender.
pub fn spawn(
&mut self,
duration: Duration,
callback: Callback<()>
) -> IntervalTask[src]
&mut self,
duration: Duration,
callback: Callback<()>
) -> IntervalTask
Sets interval which will call send a messages returned by a converter on every intarval expiration.