[−][src]Module yew_stdweb::services::reader
Service to load files using FileReader.
Structs
| Blob | A reference to a JavaScript object which implements the IBlob interface. |
| File | The File interface provides information about files and allows JavaScript in a web page to access their content. |
| FileData | Struct that represents data of a file. |
| ReaderService | A reader service attached to a user context. |
| ReaderTask | A handle to control reading. |
Enums
| FileChunk | Struct that represents a chunk of a file. |
Traits
| IBlob | A blob object represents a file-like object of immutable, raw data. Blobs represent data that isn't necessarily in a JavaScript-native format. |