[−][src]Module yew_stdweb::services::resize
This module contains the implementation of a service that listens for browser window resize events.
Structs
| ResizeService | A service that fires events when the browser window resizes. |
| ResizeTask | A handle to the event listener for resize events. |
| WindowDimensions | Dimensions of the window. |